@@ -1,6 +1,8 @@
 import math
 
-import graph_props as m
+# import graph_props as m
+
+import cofffee.graph_props as m
 
 
 def round_dig(num, dig):
